qof | Quickly Organize Files!
===

**This cross-platform app was generated by** [Briefcase](https://briefcase.readthedocs.io/) **- part of**
[The BeeWare Project](https://beeware.org/). **If you want to see more tools like Briefcase, please
consider** [becoming a financial member of BeeWare](https://beeware.org/contributing/membership).

qof | Quickly Organize Files!

```Tired of messy folders all over your device? My app makes organization easy and efficient. With just some adjusted settings to your preference, you can quickly sort your files by their extensions into renameable folders. Whether it's documents, images, videos or python files :), everything can find its destination.```

Tutorials
===
**devs_des1re:** 
- **Long Form:** https://youtu.be/CYn6uMCGKEM
- **Short:** https://www.youtube.com/shorts/5JaeavMPJ4E
<img src="https://i.ibb.co/F4pbtb1Y/New-Project.png">

How to use?
===
**1.** Of course you have to download the file first! *[Click Here](https://github.com/devs-des1re/qof/releases/tag/v1.0.0/qof.v1.0.0.msi/)*

**2.** Once you have finished the installtion, open up the app. From there select a folder you want to organize.

**3.** Add to the table, *the name of the folder*, *the extension of the files*. Don't worry if you close the app. The table *should* be saved. If not let me know.

**4.** Click organize and boom! Done in a flash.

Debugging
===
If you have an error, click *F9*, a console will pop up. Read the error and try to understand it. If you don't, you can either use google or ask me. It might be a admin restriction.

Logs
===

**v1.0.0** - First release of qof!

**v1.1.0:**
- Added icon to the Debugger console
- Removed case sensitive extension feature

Notes
===
- ~~The extensions column is case sensitive for your information~~
- Don't add a period to the extensions column otherwise it won't work





